<?php

use Tygh\Addons\RusTaxes\TaxType;
use Tygh\Registry;
use Tygh\Settings;
use Tygh\Http;

if (!defined('AREA')) {
    die('Access denied');
}

require_once __DIR__ . DIRECTORY_SEPARATOR . 'init' . DIRECTORY_SEPARATOR . 'VtbApi.php';

function fn_vtbpayments_install()
{
    $processorData = [
        'processor' => 'VtbPayments',
        'processor_script' => 'vtbpayments.php',
        'processor_template' => 'views/orders/components/payments/cc_outside.tpl',
        'admin_template' => 'vtbpayments.tpl',
        'callback' => 'Y',
        'type' => 'P',
        'position' => 10,
        'addon' => 'vtbpayments',
    ];

    $processorId = db_get_field(
        'SELECT processor_id FROM ?:payment_processors WHERE admin_template = ?s',
        $processorData['admin_template']
    );

    if (empty($processorId)) {
        db_query('INSERT INTO ?:payment_processors ?e', $processorData);
    } else {
        db_query('UPDATE ?:payment_processors SET ?u WHERE processor_id = ?i', $processorData, $processorId);
    }
}

function fn_vtbpayments_uninstall()
{
    $adminTpl = 'vtbpayments.tpl';

    $paymentIds = db_get_fields(
        'SELECT a.payment_id FROM ?:payments AS a'
        . ' LEFT JOIN ?:payment_processors AS b ON a.processor_id = b.processor_id'
        . ' WHERE b.admin_template = ?s',
        $adminTpl
    );
    foreach ($paymentIds as $paymentId) {
        fn_delete_payment($paymentId);
    }
    db_query('DELETE FROM ?:payment_processors WHERE admin_template = ?s', $adminTpl);

    $processorId = db_get_field("SELECT processor_id FROM ?:payment_processors WHERE admin_template = ?s", $adminTpl);
    if (!empty($processorId)) {
        db_query("UPDATE ?:payments SET processor_id = 0, status = 'D' WHERE processor_id = ?i", $processorId);
    }
}

function fn_vtbpayments_callback_response($code, $msg = '')
{
    header('Content-Type: application/json');
    echo json_encode(['code' => $code, 'msg' => $msg]);
}

function fn_vtbpayments_exit_with_response($code, $msg = '')
{
    fn_vtbpayments_callback_response($code, $msg);
    die();
}

function fn_vtbpayments_order_placement_routines($orderId, $forceNotification, $orderInfo, $_error)
{
    if (AREA == "C" && isset(Tygh::$app['session']['repay']) && Tygh::$app['session']['repay'] == $orderId) {
        Tygh::$app['session']['notifications'] = [];
        if (isset($forceNotification['vtbpayments'])) {
            if ($forceNotification['vtbpayments'] == 'finish_success') {
                fn_set_notification('N', __('vtbpayments_order_desc_prefix') . $orderId, __('text_order_repayed_successfully'));
            } elseif ($forceNotification['vtbpayments'] == 'finish_fail') {
                fn_set_notification('W', __('vtbpayments_order_desc_prefix') . $orderId, __('vtbpayments_payment_failed'));
            }
        }
        $redirectUrl = "orders.details&order_id=" . $orderId;
        fn_redirect($redirectUrl);
    }
}