<?php

if (!defined('BOOTSTRAP')) {
    die('Access denied');
}

use vtbpayments\VtbApi;

const VTBPAYMENTS_RESULT_SUCCESS = 0;
const VTBPAYMENTS_RESULT_ERROR_INVALID_ORDER = 10;
const VTBPAYMENTS_RESULT_ERROR_NOT_ACCEPTED = 11;

if (defined('PAYMENT_NOTIFICATION')) {

    // Finish route
    if (in_array($mode, ['finish_success', 'finish_fail'])) {
        $force_notification = [
            'vtbpayments' => $mode
        ];

        $msg = ["Платеж" => "Провалился"];
        if ($mode == 'finish_success') {
            $msg = ["Платеж" => "Проведен"];
        }
        writeLogVtbPayments($msg, 'VtbPayments.log');

        fn_order_placement_routines('route', $_REQUEST['order_id'], $force_notification);
        exit;
    }

    writeLogVtbPayments($_REQUEST, 'VtbPayments.log');

    if (empty($_REQUEST['orderId'])) {
        fn_vtbpayments_exit_with_response(VTBPAYMENTS_RESULT_ERROR_NOT_ACCEPTED, 'Invalid POST data');
    }

    $order_id = intval($_REQUEST['orderId']);
    $payment_id = db_get_field("SELECT payment_id FROM ?:orders WHERE order_id = ?i", $order_id);
    $processor_data = fn_get_processor_data($payment_id);

    if (!$processor_data) {
        fn_vtbpayments_exit_with_response(VTBPAYMENTS_RESULT_ERROR_INVALID_ORDER, 'Order not found');
    }

    writeLogVtbPayments(["Проверки" => "Пройдены"], 'VtbPayments.log');

    switch ($mode) {
        case 'check':

            $vtbRequest = new VtbApi(
                $processor_data['processor_params']['client_id'],
                $processor_data['processor_params']['client_secret'],
                $processor_data['processor_params']['client_merchant'],
                $processor_data['processor_params']['workmode']
            );

            $checkOrder = $vtbRequest->getOrderInfo($order_id);

            $check = 0;
            if (is_array($checkOrder) &&
                $checkOrder['type'] === 'ORDER' &&
                isset($checkOrder['object']) &&
                isset($checkOrder['object']['status']) &&
                !empty($checkOrder['object']['status']['value']) &&
                $checkOrder['object']['status']['value'] === 'PAID'
            ) {
                $check = 1;
            }

            if (empty($checkOrder['object']['transactions'])) {
                $check = 0;
            }

            if (!empty($checkOrder['error'])) {
                $check = 0;
            }

            if ($checkOrder && $check) {
                $pp_response['order_status'] = $processor_data['processor_params']['statuses']['paid'];
                $pp_response['reason_text'] = __('approved');
                fn_update_order_payment_info($order_id, $pp_response);
                fn_change_order_status($order_id, $pp_response['order_status']);
                fn_redirect(
                    fn_url(
                        'payment_notification.finish_success?payment=vtbpayments&order_id=' . $order_id,
                        'C',
                        'current'
                    )
                );
            }

            $pp_response['order_status'] = $processor_data['processor_params']['statuses']['failed'];
            $pp_response['reason_text'] = __('vtbpayments_payment_failed');
            fn_finish_payment($order_id, $pp_response);
            fn_redirect(
                fn_url(
                    'payment_notification.finish_fail?payment=vtbpayments&order_id=' . $order_id,
                    'C',
                    'current'
                )
            );
            break;
        default:
            fn_vtbpayments_exit_with_response(VTBPAYMENTS_RESULT_ERROR_NOT_ACCEPTED, 'Invalid action');
    }

    fn_vtbpayments_callback_response(VTBPAYMENTS_RESULT_SUCCESS);
} else {
    /**
     * @var array $processor_data
     * @var array $order_info
     */

    $vtbRequest = new VtbApi(
        $processor_data['processor_params']['client_id'],
        $processor_data['processor_params']['client_secret'],
        $processor_data['processor_params']['client_merchant'],
        $processor_data['processor_params']['workmode']
    );

    $order_id = (!empty($order_id)) ? $order_id : $order_info['order_id'];

    if (isset(Tygh::$app['session']['cart']['placement_action']) &&
        Tygh::$app['session']['cart']['placement_action'] == "repay"
    ) {
        Tygh::$app['session']['repay'] = $order_id;
    }

    // Check discount
    $total = fn_format_price_by_currency(
        $order_info['total'],
        CART_PRIMARY_CURRENCY,
        $processor_data['processor_params']['currency']
    );

    $amount = $total;
    $discount = $total - $order_info['subtotal'];
    if ($discount === $order_info['subtotal_discount']) {
        $amount = $order_info['subtotal'];
    }

    $response = $vtbRequest->getOrderLink(
        $order_info['order_id'],
        $order_info['email'],
        $order_info['timestamp'],
        $amount
    );

    $result = false;
    if (is_array($response) &&
        $response['type'] === 'ORDER' &&
        isset($response['object']) &&
        isset($response['object']['payUrl']) &&
        !empty($response['object']['payUrl'])
    ) {
        $result = $response['object']['payUrl'];
    }

    // We need redirect client
    if ($result) {
        header("Location: {$result}", true, 302);
        die;
    } else {
        writeLogVtbPayments('Something wrong :(, order not created', 'VtbPayments.log');
        fn_vtbpayments_exit_with_response(VTBPAYMENTS_RESULT_ERROR_INVALID_ORDER, 'Something wrong :(, order not created');
    }
}

function writeLogVtbPayments($data, $file = 'VtbPayments.log')
{
    $path = fn_get_files_dir_path();
    fn_mkdir($path);
    $file = fopen($path . $file, 'a');

    if (!empty($file)) {
        fputs($file, 'TIME: ' . date('Y-m-d H:i:s', TIME) . "\n");
        fputs($file, fn_array2code_string($data) . "\n\n");
        fclose($file);
    }
}

exit;